@@ -2,6 +2,10 @@
 set -euo pipefail
 IFS=$'\n\t'
 
+# set git hooks
+ln -s -f ../../githooks/pre-commit .git/hooks/pre-commit
+# set blame ignore file
+git config blame.ignorerevsfile .git-blame-ignore-revs
 
 # Get number of CPU cores
 CPUS=$(getconf _NPROCESSORS_ONLN 2>/dev/null || getconf NPROCESSORS_ONLN 2>/dev/null || echo 1)
@@ -36,8 +40,25 @@ else
   POETRY_BIN=`echo ~/.local/bin/poetry` # expand tilde
 fi
 $POETRY_BIN self add 'poetry-dynamic-versioning[plugin]'
+poetry run pip install autopep8
 echo "Done installing dependencies"
 
+echo "Downloading uncrustify source code"
+wget -c -q https://github.com/uncrustify/uncrustify/archive/refs/tags/uncrustify-0.78.1.tar.gz
+mkdir -p uncrustify-source
+tar -xzvf uncrustify-0.78.1.tar.gz -C uncrustify-source --strip-components=1 # strip the root folder
+echo "Done downloading uncrustify source code"
+
+echo "Building uncrustify"
+cd uncrustify-source
+mkdir -p build
+cd build
+cmake ../
+make -j4
+cp uncrustify ../../uncrustify
+cd ../..
+echo "Done building uncrustify"
+
 echo "Downloading spidermonkey source code"
 wget -c -q https://ftp.mozilla.org/pub/firefox/releases/115.8.0esr/source/firefox-115.8.0esr.source.tar.xz
 mkdir -p firefox-source
@@ -77,4 +98,4 @@ if [[ "$OSTYPE" == "darwin"* ]]; then # macOS
   # overrides https://hg.mozilla.org/releases/mozilla-esr102/file/89d799cb/js/src/build/Makefile.in#l83
   install_name_tool -id @rpath/$(basename ./libmozjs*) ./libmozjs* # making it work for whatever name the libmozjs dylib is called
 fi
-echo "Done installing spidermonkey"
+echo "Done installing spidermonkey"
\ No newline at end of file
