@@ -17,26 +17,26 @@
 #include <jsapi.h>
 #include <js/Exception.h>
 
-#include <Python.h>
 #include <frameobject.h>
 
 
 // TODO (Tom Tang): preserve the original Python exception object somewhere in the JS obj for lossless two-way conversion
 
-ExceptionType::ExceptionType(JSContext *cx, JS::HandleObject error) {
+PyObject *ExceptionType::getPyObject(JSContext *cx, JS::HandleObject error) {
   // Convert the JS Error object to a Python string
   JS::RootedValue errValue(cx, JS::ObjectValue(*error)); // err
   JS::RootedObject errStack(cx, JS::ExceptionStackOrNull(error)); // err.stack
   PyObject *errStr = getExceptionString(cx, JS::ExceptionStack(cx, errValue, errStack), true);
 
   // Construct a new SpiderMonkeyError python object
-  //    pyObject = SpiderMonkeyError(errStr)
   #if PY_VERSION_HEX >= 0x03090000
-  pyObject = PyObject_CallOneArg(SpiderMonkeyError, errStr); // _PyErr_CreateException, https://github.com/python/cpython/blob/3.9/Python/errors.c#L100
+  PyObject *pyObject = PyObject_CallOneArg(SpiderMonkeyError, errStr); // _PyErr_CreateException, https://github.com/python/cpython/blob/3.9/Python/errors.c#L100
   #else
-  pyObject = PyObject_CallFunction(SpiderMonkeyError, "O", errStr); // PyObject_CallOneArg is not available in Python < 3.9
+  PyObject *pyObject = PyObject_CallFunction(SpiderMonkeyError, "O", errStr); // PyObject_CallOneArg is not available in Python < 3.9
   #endif
   Py_XDECREF(errStr);
+
+  return pyObject;
 }
 
 
@@ -80,7 +80,10 @@ JSObject *ExceptionType::toJsError(JSContext *cx, PyObject *exceptionValue, PyOb
   assert(exceptionValue != NULL);
 
   // Gather JS context
+  #pragma GCC diagnostic push
+  #pragma GCC diagnostic ignored "-Wformat-zero-length"
   JS_ReportErrorASCII(cx, ""); // throw JS error and gather all details
+  #pragma GCC diagnostic pop
 
   JS::ExceptionStack exceptionStack(cx);
   if (!JS::GetPendingExceptionStack(cx, &exceptionStack)) {
@@ -93,7 +96,7 @@ JSObject *ExceptionType::toJsError(JSContext *cx, PyObject *exceptionValue, PyOb
   if (stackObj.get()) {
     JS::RootedString stackStr(cx);
     JS::BuildStackString(cx, nullptr, stackObj, &stackStr, 2, js::StackFormat::SpiderMonkey);
-    stackStream << "\nJS Stack Trace:\n" << StrType(cx, stackStr).getValue();
+    stackStream << "\nJS Stack Trace:\n" << StrType::getValue(cx, stackStr);
   }
 
 
