@@ -34,6 +34,11 @@ int JSArrayIterProxyMethodDefinitions::JSArrayIterProxy_traverse(JSArrayIterProx
   return 0;
 }
 
+int JSArrayIterProxyMethodDefinitions::JSArrayIterProxy_clear(JSArrayIterProxy *self) {
+  Py_CLEAR(self->it.it_seq);
+  return 0;
+}
+
 PyObject *JSArrayIterProxyMethodDefinitions::JSArrayIterProxy_iter(JSArrayIterProxy *self) {
   Py_INCREF(&self->it);
   return (PyObject *)&self->it;
@@ -49,14 +54,14 @@ PyObject *JSArrayIterProxyMethodDefinitions::JSArrayIterProxy_next(JSArrayIterPr
     if (self->it.it_index >= 0) {
       JS::RootedValue elementVal(GLOBAL_CX);
       JS_GetElement(GLOBAL_CX, *(((JSArrayProxy *)seq)->jsArray), self->it.it_index--, &elementVal);
-      return pyTypeFactory(GLOBAL_CX, elementVal)->getPyObject();
+      return pyTypeFactory(GLOBAL_CX, elementVal);
     }
   }
   else {
     if (self->it.it_index < JSArrayProxyMethodDefinitions::JSArrayProxy_length((JSArrayProxy *)seq)) {
       JS::RootedValue elementVal(GLOBAL_CX);
       JS_GetElement(GLOBAL_CX, *(((JSArrayProxy *)seq)->jsArray), self->it.it_index++, &elementVal);
-      return pyTypeFactory(GLOBAL_CX, elementVal)->getPyObject();
+      return pyTypeFactory(GLOBAL_CX, elementVal);
     }
   }
 
