@@ -53,6 +53,11 @@ int JSObjectKeysProxyMethodDefinitions::JSObjectKeysProxy_traverse(JSObjectKeysP
   return 0;
 }
 
+int JSObjectKeysProxyMethodDefinitions::JSObjectKeysProxy_clear(JSObjectKeysProxy *self) {
+  Py_CLEAR(self->dv.dv_dict);
+  return 0;
+}
+
 // private
 static int all_contained_in(PyObject *self, PyObject *other) {
   PyObject *iter = PyObject_GetIter(self);
