@@ -61,7 +61,7 @@ PyObject *getExceptionString(JSContext *cx, const JS::ExceptionStack &exceptionS
     if (stackObj.get()) {
       JS::RootedString stackStr(cx);
       BuildStackString(cx, nullptr, stackObj, &stackStr, 2, js::StackFormat::SpiderMonkey);
-      outStrStream << "Stack Trace:\n" << StrType(cx, stackStr).getValue();
+      outStrStream << "Stack Trace:\n" << StrType::getValue(cx, stackStr);
     }
   }
 
